tzif/loader
Values
pub fn load_from_os() -> Result(database.TzDatabase, Nil)
Load time zone database from default operating system location
which is typically “/usr/share/zoneinfo”. If no parsable TZif
files were found, returns Error(Nil).
pub fn load_from_path(
path: String,
) -> Result(database.TzDatabase, Nil)
Load time zone database from provided directory. This is
useful if you have compiled your own version of the IANA
time zone database
or they are not stored in the standard location. If no
parsable TZif files were found, returns Error(Nil).